import { sortApplicationsByCreationDate } from './helper'
import { describe, it, expect } from '@jest/globals'
import type { ApplicationType } from './routes/application.type'

describe('sortApplicationsByCreationDate', () => {
  it('should return a sorted array of applications in descending order of creation date', () => {
    const applications: ApplicationType[] = [
      {
        id: 1,
        name: 'App 1',
        created_at: '2023-05-01T10:00:00Z'
      } as ApplicationType,
      {
        id: 2,
        name: 'App 2',
        created_at: '2023-05-03T10:00:00Z'
      } as ApplicationType,
      {
        id: 3,
        name: 'App 3',
        created_at: '2023-05-02T10:00:00Z'
      } as ApplicationType
    ]

    const sortedApplications = sortApplicationsByCreationDate(applications)

    expect(sortedApplications).toEqual([
      {
        id: 2,
        name: 'App 2',
        created_at: '2023-05-03T10:00:00Z'
      } as ApplicationType,
      {
        id: 3,
        name: 'App 3',
        created_at: '2023-05-02T10:00:00Z'
      } as ApplicationType,
      {
        id: 1,
        name: 'App 1',
        created_at: '2023-05-01T10:00:00Z'
      } as ApplicationType
    ])
  })

  it('should handle an empty array of applications without errors', () => {
    const emptyApplications: ApplicationType[] = []
    const sortedApplications = sortApplicationsByCreationDate(emptyApplications)
    expect(sortedApplications).toEqual([])
  })

  it('should return the same array if all applications have the same creation date', () => {
    const applications: ApplicationType[] = [
      {
        id: 1,
        name: 'App 1',
        created_at: '2023-05-01T10:00:00Z'
      } as ApplicationType,
      {
        id: 2,
        name: 'App 2',
        created_at: '2023-05-01T10:00:00Z'
      } as ApplicationType,
      {
        id: 3,
        name: 'App 3',
        created_at: '2023-05-01T10:00:00Z'
      } as ApplicationType
    ]

    const sortedApplications = sortApplicationsByCreationDate(applications)

    expect(sortedApplications).toEqual(applications)
    expect(sortedApplications).not.toBe(applications) // Ensure a new array is returned
  })

  it('should correctly sort applications with different dates and times', () => {
    const applications: ApplicationType[] = [
      {
        id: 1,
        name: 'App 1',
        created_at: '2023-05-01T10:30:00Z'
      } as ApplicationType,
      {
        id: 2,
        name: 'App 2',
        created_at: '2023-05-01T11:00:00Z'
      } as ApplicationType,
      {
        id: 3,
        name: 'App 3',
        created_at: '2023-05-01T10:45:00Z'
      } as ApplicationType
    ]

    const sortedApplications = sortApplicationsByCreationDate(applications)

    expect(sortedApplications).toEqual([
      {
        id: 2,
        name: 'App 2',
        created_at: '2023-05-01T11:00:00Z'
      } as ApplicationType,
      {
        id: 3,
        name: 'App 3',
        created_at: '2023-05-01T10:45:00Z'
      } as ApplicationType,
      {
        id: 1,
        name: 'App 1',
        created_at: '2023-05-01T10:30:00Z'
      } as ApplicationType
    ])
  })
})
