export interface AddApplicationParams {
  name: string
  tags: string
  planId: string
  redirectUrl: string
}

export interface AddApplicationResponse {
  redirect_url: string
  order_id: string
  application_id: number
}

export interface GetApplicationParams {
  productId: string
  page: number
  perPage: number
}

export interface ActiveQuota {
  name: string
  type: string
  units_start: number
  units_now: number
  capability_key: string
  expired_at?: string
  unit_name?: string
  is_expired: boolean
  prev_unused_quota?: number
}

export interface ApplicationType {
  id: number
  name: string
  created_at: string
  plan_name: string
  plan_id: number
  product_name: string
  product_id: number
  is_activated: boolean
  active_quotas: ActiveQuota[]
}

export interface ApplicationPlan {
  id: number
  name: string
  type: 'fixed' | 'volume' | 'trial'
}

export interface ApiKey {
  label: string
  key: string
  created_at: string
  unique_key: string
}

export interface LatestTransaction {
  id: number
  order_id: string
  payment_link: string
  plan_id: number
  status: string
  action: string
}

export interface ApplicationDetailType {
  id: number
  name: string
  tags: string
  created_at: string
  plan: ApplicationPlan
  is_activated: boolean
  api_keys: ApiKey[]
  active_quotas: ActiveQuota[]
  latest_transaction: LatestTransaction
  freemium_active_quotas?: ActiveQuota[]
}

export interface LicenseKey {
  key: string
  customer?: number
  plan?: number
  is_activated: boolean
  activation_time: string
  client_cert: string
  created_at: string
  updated_at: string
}

export interface Application {
  id: number
  name: string
  customer_id: string
  license_key: LicenseKey
  tags: string
  deleted: boolean
  created_at: string
  updated_at: string
}

export interface CreateApiKeyResponse {
  key: string
  application: Application
  label: string
  unique_key: string
  expired_at: string
  created_at: string
  updated_at?: string
}

export interface DowngradeApplicationPlanBody {
  plan_id: number
  capability_key: string
}

export interface GetApplicationQuotaHistoryParams {
  page: number
  page_size: number
  quota_type_include: string[]
  quota_type_exclude: string[]
}

export interface QuotaHistoryResponse {
  history: QuotaHistory[]
  page: number
  page_size: number
  total_size: number
}

export interface QuotaHistory {
  plan_name: string
  capability_name: string
  quota_type: string
  keyword: string
  units_change: number
  units_after: number
  created_at: string
  duration: string
}

export interface RenewApplicationBody {
  plan_id: number
  redirect_url: string
  conversion?: {
    referral_code: string
  }
  voucher_code?: string
}
