import { consoleApiAxios } from '../config'
import { handleAxiosError } from '../errorHandler'
import type { AxiosRequestConfig } from 'axios'
import type { VerifyReferralCodeResponse } from './conversion.type'

/**
 * Verifies a conversion referral code for a specific product.
 *
 * @param accessToken - The access token for authentication.
 * @param referralCode - The referral code to verify.
 * @returns A promise that resolves to a tuple where the first element is the response data if successful,
 *          and the second element is an Error if an error occurred.
 */
export const verifyReferralCode = async (
  accessToken: string,
  referralCode: string
) => {
  const requestConfig: AxiosRequestConfig = {
    headers: {
      Authorization: `Bearer ${accessToken}`
    }
  }

  return handleAxiosError(
    consoleApiAxios.post<VerifyReferralCodeResponse>(
      `/admin/conversion/verify/`,
      {
        referral_code: referralCode,
        product_id: process.env.PRODUCT_ID
      },
      requestConfig
    )
  )
}
