import { consoleApiAxios } from '../config'
import { handleAxiosError } from '../errorHandler'
import type { AxiosRequestConfig } from 'axios'
import type { ConsoleNotificationResponse } from './notification.type'

/**
 * Deletes a notification with the specified ID.
 *
 * @param accessToken - The access token for authentication.
 * @param id - The unique identifier of the notification to delete.
 * @returns A promise that resolves to a tuple where the first element is the response data if successful,
 *          and the second element is an Error if an error occurred.
 */
export const deleteNotification = async (accessToken: string, id: string) => {
  const requestConfig: AxiosRequestConfig = {
    headers: {
      Authorization: `Bearer ${accessToken}`
    }
  }

  return handleAxiosError(
    consoleApiAxios.delete<unknown>(`/admin/notification/${id}/`, requestConfig)
  )
}

/**
 * Retrieves the list of saved notifications.
 *
 * @param accessToken - The access token for authentication.
 * @returns A promise that resolves to a tuple where the first element is the response data if successful,
 *          and the second element is an Error if an error occurred.
 */
export const getNotifications = async (accessToken: string) => {
  const requestConfig: AxiosRequestConfig = {
    headers: {
      Authorization: `Bearer ${accessToken}`
    }
  }

  return handleAxiosError(
    consoleApiAxios.get<ConsoleNotificationResponse>(
      `/admin/notification/saved/`,
      requestConfig
    )
  )
}
