import { consoleApiAxios } from '../config'
import { handleAxiosError } from '../errorHandler'
import type { AxiosRequestConfig } from 'axios'
import type { Plan } from './plan.type'

/**
 * Retrieves a plan based on the provided product ID.
 *
 * @param productId - The unique identifier of the product for which to fetch the plan.
 * @returns A Promise that resolves to the Plan object associated with the given product ID.
 * @throws Will throw an error if the API request fails, which is handled by the handleAxiosError function.
 */
export const getPlan = async (productId: string) => {
  const requestConfig: AxiosRequestConfig = {
    params: {
      product_id: productId
    }
  }

  return handleAxiosError(
    consoleApiAxios.get<Plan>('/admin/plan/', requestConfig)
  )
}
