import { consoleApiAxios } from '../config'
import { handleAxiosError } from '../errorHandler'
import type { AxiosRequestConfig } from 'axios'
import type { UpdateProfileRequestBody } from './profile.type'

/**
 * Updates the user's profile with the provided information.
 *
 * @param accessToken - The access token for authentication.
 * @param body - The updated profile data to be sent in the request body.
 * @returns A promise that resolves to a tuple where the first element is the response data if successful,
 *          and the second element is an Error if an error occurred.
 */
export const updateUserProfile = async (
  accessToken: string,
  body: UpdateProfileRequestBody
) => {
  const requestConfig: AxiosRequestConfig = {
    headers: {
      Authorization: `Bearer ${accessToken}`
    }
  }

  return handleAxiosError(
    consoleApiAxios.put<unknown>(`/admin/profile/`, body, requestConfig)
  )
}
