import { consoleApiAxios } from '../config'
import { handleAxiosError } from '../errorHandler'
import type { AxiosRequestConfig } from 'axios'
import type {
  GetTransactionsParams,
  TransactionResponse
} from './transaction.type'

/**
 * Fetches transactions from the admin transaction endpoint.
 *
 * @param accessToken - The bearer token used for authentication.
 * @param params - An object containing parameters for the transaction query.
 * @returns A promise that resolves to the transaction response, or rejects with an error.
 */
export const getTransactions = async (
  accessToken: string,
  params: GetTransactionsParams
) => {
  const config: AxiosRequestConfig = {
    headers: {
      Authorization: `Bearer ${accessToken}`
    },
    params,
    paramsSerializer: {
      indexes: null
    }
  }

  return handleAxiosError(
    consoleApiAxios.get<TransactionResponse>(`/admin/transaction/`, config)
  )
}
